/***************************************************************************//**
*   @file   main.c
*   @brief  Main File for AD5160 Driver.
*   @author ATofan (alexandru.tofan@analog.com)
********************************************************************************
* Copyright 2012(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
********************************************************************************
*   SVN Revision: $WCREV$
*******************************************************************************/

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/
#include <stdio.h>
#include "xparameters.h"
#include "xil_cache.h"
#include "xil_io.h"
#include "spi.h"
#include "AD5160.h"

void uartIntHandler(void);

volatile int rxData = 0;
int main() 
{
	Xil_ICacheEnable();
	Xil_DCacheEnable();

	SPI_Init(SPI_BASEADDR, 0, 0, 0);

	microblaze_register_handler((XInterruptHandler)uartIntHandler, (void *)0);
	Xil_Out32(UART_BASEADDR + 0x0C, (1 << 4));
	microblaze_enable_interrupts();

	AD5160_DisplayMainMenu();

	while(1)
	{
		switch(rxData)
		{
			case 'd':
				AD5160_Set();
				break;
			case 'c':
				AD5160_CalibrateRab();
				AD5160_CalibrateRwp();
				break;
			case 'm':
				AD5160_DisplayMenu();
				break;
			case 0:
				break;
			default:
				xil_printf("\n\rWrong option! Please select one of the options below.");
				AD5160_DisplayMenu();
				break;
		}
	}

	Xil_DCacheDisable();
	Xil_ICacheDisable();

	return 0;
}

/******************************************************************************
* @brief Interrupt Handler for UART.
*
* @return None.
******************************************************************************/
void uartIntHandler(void)
{
	if(Xil_In32(XPAR_USB_UART_BASEADDR + 0x08) & 0x01)
	{
		rxData = Xil_In32(XPAR_USB_UART_BASEADDR);
	}
}
